changeset 11061:2f41090c58b3

(isearch-abort): Treat "incomplete regexp" as failure when deciding how much to discard for C-g.
author Richard M. Stallman <rms@gnu.org>
date Sat, 18 Mar 1995 18:10:21 +0000
parents 0a7048d331e6
children 302f676eeca0
files lisp/isearch.el
diffstat 1 files changed, 5 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/isearch.el	Sat Mar 18 18:05:28 1995 +0000
+++ b/lisp/isearch.el	Sat Mar 18 18:10:21 1995 +0000
@@ -4,7 +4,7 @@
 
 ;; Author: Daniel LaLiberte <liberte@cs.uiuc.edu>
 
-;; |$Date: 1995/01/11 02:24:09 $|$Revision: 1.83 $
+;; |$Date: 1995/03/16 23:31:39 $|$Revision: 1.84 $
 
 ;; This file is part of GNU Emacs.
 
@@ -800,8 +800,10 @@
 	     (setq isearch-success nil)
 	     (isearch-done t)   ; exit isearch
 	     (signal 'quit nil))  ; and pass on quit signal
-    ;; If search is failing, rub out until it is once more successful.
-    (while (not isearch-success) (isearch-pop-state))
+    ;; If search is failing, or has an incomplete regexp,
+    ;; rub out until it is once more successful.
+    (while (or (not isearch-success) isearch-invalid-regexp)
+      (isearch-pop-state))
     (isearch-update)))
 
 (defun isearch-repeat (direction)